EXPORTS
	?Connect@RStarterSession@@QAEHXZ @ 1 NONAME ; int RStarterSession::Connect(void)
	?SetState@RStarterSession@@QAEHW4TGlobalState@1@@Z @ 2 NONAME ; int RStarterSession::SetState(enum RStarterSession::TGlobalState)
	?Reset@RStarterSession@@QAEXW4TResetReason@1@@Z @ 3 NONAME ; void RStarterSession::Reset(enum RStarterSession::TResetReason)
	?Shutdown@RStarterSession@@QAEXXZ @ 4 NONAME ; void RStarterSession::Shutdown(void)
	?ActivateRfForEmergencyCall@RStarterSession@@QAEHXZ @ 5 NONAME ; int RStarterSession::ActivateRfForEmergencyCall(void)
	?DeactivateRfAfterEmergencyCall@RStarterSession@@QAEHXZ @ 6 NONAME ; int RStarterSession::DeactivateRfAfterEmergencyCall(void)
	?AddItemInStartListL@RStarterSession@@QAEHABVTDesC16@@W4TMonitoringMode@@W4TItemType@@H@Z @ 7 NONAME ABSENT ; int RStarterSession::AddItemInStartListL(class TDesC16 const &, enum TMonitoringMode, enum TItemType, int)
	?RemoveItemFromStartListL@RStarterSession@@QAEHABVTDesC16@@@Z @ 8 NONAME ABSENT ; int RStarterSession::RemoveItemFromStartListL(class TDesC16 const &)
	?SearchStartlistL@RStarterSession@@QAEHABVTDesC16@@@Z @ 9 NONAME ABSENT ; int RStarterSession::SearchStartlistL(class TDesC16 const &)
	?AddItemInStartListL@RStarterSession@@QAEHABVTDesC16@@W4TMonitoringMode@@W4TItemType@@HVTPtrC8@@@Z @ 10 NONAME ABSENT ; int RStarterSession::AddItemInStartListL(class TDesC16 const &, enum TMonitoringMode, enum TItemType, int, class TPtrC8)
	?IsRTCTimeValid@RStarterSession@@QAEHXZ @ 11 NONAME ; int RStarterSession::IsRTCTimeValid(void)
	?EndSplashScreen@RStarterSession@@QAEHXZ @ 12 NONAME ; int RStarterSession::EndSplashScreen(void)
	?ResetNetwork@RStarterSession@@QAEHXZ @ 13 NONAME ; int RStarterSession::ResetNetwork(void)

